djangocms-text-mediumeditor
===========================

Text plugin for [Django CMS][0] which uses [MediumEditor][1] instead of
CKEditor.

Current bundled version of MediumEditor is **5.23.3**.

[0]: https://www.django-cms.org
[1]: https://yabwe.github.io/medium-editor/
